==> code-generator-1.0.1-sources.jar: cn/shazhengbo/utils/GenUtils.java <==
package cn.shazhengbo.utils;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class GenUtils
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.util.List<java.lang.String> getTemplates() { return (java.util.List<java.lang.String>)null;}
public static  org.apache.commons.configuration.Configuration getConfig() { return (org.apache.commons.configuration.Configuration)null;}
public static  void generatorCode(java.util.Map<java.lang.String, java.lang.String> table, java.util.List<java.util.Map<java.lang.String, java.lang.String>> columns, org.apache.commons.configuration.Configuration config, java.util.List<java.lang.String> templates) { }
public static  void generatorCode(java.util.Map<java.lang.String, java.lang.String> table, java.util.List<java.util.Map<java.lang.String, java.lang.String>> columns) { }
public static  java.lang.Object writerFile(java.lang.String path, java.lang.String fileName, java.lang.String context) { return null;}
public static  java.lang.String columnToJava(java.lang.String columnName) { return (java.lang.String)null;}
public static  java.lang.String tableToJava(java.lang.String tableName, java.lang.String tablePrefix) { return (java.lang.String)null;}
public static  java.lang.String getFileName(java.lang.String template, java.lang.String className) { return (java.lang.String)null;}
public static  java.lang.String getFileDir(java.lang.String template, java.lang.String packageName, java.lang.String moduleName) { return (java.lang.String)null;}
}

==> code-generator-1.0.2-sources.jar: cn/shazhengbo/utils/GenUtils.java <==
package cn.shazhengbo.utils;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class GenUtils
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.util.List<java.lang.String> getTemplates() { return (java.util.List<java.lang.String>)null;}
public static  org.apache.commons.configuration.Configuration getConfig() { return (org.apache.commons.configuration.Configuration)null;}
public static  void generatorCode(java.util.Map<java.lang.String, java.lang.String> table, java.util.List<java.util.Map<java.lang.String, java.lang.String>> columns, org.apache.commons.configuration.Configuration config, java.util.List<java.lang.String> templates) { }
public static  void generatorCode(java.util.Map<java.lang.String, java.lang.String> table, java.util.List<java.util.Map<java.lang.String, java.lang.String>> columns) { }
public static  java.lang.Object writerFile(java.lang.String path, java.lang.String fileName, java.lang.String context) { return null;}
public static  java.lang.String columnToJava(java.lang.String columnName) { return (java.lang.String)null;}
public static  java.lang.String tableToJava(java.lang.String tableName, java.lang.String tablePrefix) { return (java.lang.String)null;}
public static  java.lang.String getFileName(java.lang.String template, java.lang.String className) { return (java.lang.String)null;}
public static  java.lang.String getFileDir(java.lang.String template, java.lang.String packageName, java.lang.String moduleName) { return (java.lang.String)null;}
}
